@@ -765,7 +765,7 @@ EOF;
             }
         }
 
-        if (strpos($path, '.phar') !== false) {
+        if (Preg::isMatch('{\.phar([\\\\/]|$)}', $path)) {
             $baseDir = "'phar://' . " . $baseDir;
         }
 
@@ -975,10 +975,7 @@ if (PHP_VERSION_ID < 50600) {
             echo \$err;
         }
     }
-    trigger_error(
-        \$err,
-        E_USER_ERROR
-    );
+    throw new RuntimeException(\$err);
 }
 
 require_once $vendorPathToTargetDirCode;
