@@ -53,7 +53,7 @@ class Cache
         $this->root = rtrim($cacheDir, '/\\') . '/';
         $this->allowlist = $allowlist;
         $this->filesystem = $filesystem ?: new Filesystem();
-        $this->readOnly = (bool) $readOnly;
+        $this->readOnly = $readOnly;
 
         if (!self::isUsable($cacheDir)) {
             $this->enabled = false;
@@ -65,7 +65,7 @@ class Cache
      */
     public function setReadOnly(bool $readOnly)
     {
-        $this->readOnly = (bool) $readOnly;
+        $this->readOnly = $readOnly;
     }
 
     /**
@@ -144,7 +144,7 @@ class Cache
 
             $this->io->writeError('Writing '.$this->root . $file.' into cache', true, IOInterface::DEBUG);
 
-            $tempFileName = $this->root . $file . uniqid('.', true) . '.tmp';
+            $tempFileName = $this->root . $file . bin2hex(random_bytes(5)) . '.tmp';
             try {
                 return file_put_contents($tempFileName, $contents) !== false && rename($tempFileName, $this->root . $file);
             } catch (\ErrorException $e) {
@@ -198,7 +198,7 @@ class Cache
                 $this->io->writeError('Writing '.$this->root . $file.' into cache from '.$source);
             }
 
-            return copy($source, $this->root . $file);
+            return $this->filesystem->copy($source, $this->root . $file);
         }
 
         return false;
@@ -224,7 +224,7 @@ class Cache
 
                 $this->io->writeError('Reading '.$this->root . $file.' from cache', true, IOInterface::DEBUG);
 
-                return copy($this->root . $file, $target);
+                return $this->filesystem->copy($this->root . $file, $target);
             }
         }
 
@@ -357,7 +357,7 @@ class Cache
         if ($this->isEnabled()) {
             $file = Preg::replace('{[^'.$this->allowlist.']}i', '-', $file);
             if (file_exists($this->root . $file)) {
-                return sha1_file($this->root . $file);
+                return hash_file('sha1', $this->root . $file);
             }
         }
 
