@@ -12,6 +12,7 @@
 
 namespace Composer\Command;
 
+use Composer\Advisory\Auditor;
 use Composer\Pcre\Preg;
 use Composer\Util\Filesystem;
 use Composer\Util\Platform;
@@ -290,7 +291,7 @@ EOT
             $source = $this->config->getSourceOfValue($settingKey);
 
             if (Preg::isMatch('/^repos?(?:itories)?(?:\.(.+))?/', $settingKey, $matches)) {
-                if (!isset($matches[1]) || $matches[1] === '') {
+                if (!isset($matches[1])) {
                     $value = $data['repositories'] ?? [];
                 } else {
                     if (!isset($data['repositories'][$matches[1]])) {
@@ -468,6 +469,18 @@ EOT
             'prepend-autoloader' => [$booleanValidator, $booleanNormalizer],
             'disable-tls' => [$booleanValidator, $booleanNormalizer],
             'secure-http' => [$booleanValidator, $booleanNormalizer],
+            'bump-after-update' => [
+                static function ($val): bool {
+                    return in_array($val, ['dev', 'no-dev', 'true', 'false', '1', '0'], true);
+                },
+                static function ($val) {
+                    if ('dev' === $val || 'no-dev' === $val) {
+                        return $val;
+                    }
+
+                    return $val !== 'false' && (bool) $val;
+                },
+            ],
             'cafile' => [
                 static function ($val): bool {
                     return file_exists($val) && Filesystem::isReadable($val);
@@ -512,6 +525,14 @@ EOT
                     return $val !== 'false' && (bool) $val;
                 },
             ],
+            'audit.abandoned' => [
+                static function ($val): bool {
+                    return in_array($val, [Auditor::ABANDONED_IGNORE, Auditor::ABANDONED_REPORT, Auditor::ABANDONED_FAIL], true);
+                },
+                static function ($val) {
+                    return $val;
+                },
+            ],
         ];
         $multiConfigValues = [
             'github-protocols' => [
@@ -556,8 +577,27 @@ EOT
                     return $vals;
                 },
             ],
+            'audit.ignore' => [
+                static function ($vals) {
+                    if (!is_array($vals)) {
+                        return 'array expected';
+                    }
+
+                    return true;
+                },
+                static function ($vals) {
+                    return $vals;
+                },
+            ],
         ];
 
+        // allow unsetting audit config entirely
+        if ($input->getOption('unset') && $settingKey === 'audit') {
+            $this->configSource->removeConfigSetting($settingKey);
+
+            return 0;
+        }
+
         if ($input->getOption('unset') && (isset($uniqueConfigValues[$settingKey]) || isset($multiConfigValues[$settingKey]))) {
             if ($settingKey === 'disable-tls' && $this->config->get('disable-tls')) {
                 $this->getIO()->writeError('<info>You are now running Composer with SSL/TLS protection enabled.</info>');
@@ -636,7 +676,7 @@ EOT
             }],
             'minimum-stability' => [
                 static function ($val): bool {
-                    return isset(BasePackage::$stabilities[VersionParser::normalizeStability($val)]);
+                    return isset(BasePackage::STABILITIES[VersionParser::normalizeStability($val)]);
                 },
                 static function ($val): string {
                     return VersionParser::normalizeStability($val);
@@ -743,8 +783,12 @@ EOT
                     foreach ($bits as $bit) {
                         $currentValue = $currentValue[$bit] ?? null;
                     }
-                    if (is_array($currentValue)) {
-                        $value = array_merge($currentValue, $value);
+                    if (is_array($currentValue) && is_array($value)) {
+                        if (array_is_list($currentValue) && array_is_list($value)) {
+                            $value = array_merge($currentValue, $value);
+                        } else {
+                            $value = $value + $currentValue;
+                        }
                     }
                 }
             }
@@ -981,7 +1025,7 @@ EOT
     }
 
     /**
-     * Suggest setting-keys, while taking given options in acount.
+     * Suggest setting-keys, while taking given options in account.
      */
     private function suggestSettingKeys(): \Closure
     {
