@@ -46,7 +46,7 @@ Displays detailed information about why a package cannot be installed.
 
 <info>php composer.phar prohibits composer/composer</info>
 
-Read more at https://getcomposer.org/doc/03-cli.md#prohibits-why-not-
+Read more at https://getcomposer.org/doc/03-cli.md#prohibits-why-not
 EOT
             )
         ;
