@@ -126,7 +126,7 @@ class FileDownloader implements DownloaderInterface, ChangeReportInterface
         }
 
         $cacheKeyGenerator = static function (PackageInterface $package, $key): string {
-            $cacheKey = sha1($key);
+            $cacheKey = hash('sha1', $key);
 
             return $package->getName().'/'.$cacheKey.'.'.$package->getDistType();
         };
@@ -350,7 +350,14 @@ class FileDownloader implements DownloaderInterface, ChangeReportInterface
             $this->io->writeError("  - " . InstallOperation::format($package));
         }
 
-        $this->filesystem->emptyDirectory($path);
+        $vendorDir = $this->config->get('vendor-dir');
+
+        // clean up the target directory, unless it contains the vendor dir, as the vendor dir contains
+        // the file to be installed. This is the case when installing with create-project in the current directory
+        // but in that case we ensure the directory is empty already in ProjectInstaller so no need to empty it here.
+        if (false === strpos($this->filesystem->normalizePath($vendorDir), $this->filesystem->normalizePath($path.DIRECTORY_SEPARATOR))) {
+            $this->filesystem->emptyDirectory($path);
+        }
         $this->filesystem->ensureDirectoryExists($path);
         $this->filesystem->rename($this->getFileName($package, $path), $path . '/' . $this->getDistPath($package, PATHINFO_BASENAME));
 
@@ -441,7 +448,7 @@ class FileDownloader implements DownloaderInterface, ChangeReportInterface
             $extension = $package->getDistType();
         }
 
-        return rtrim($this->config->get('vendor-dir') . '/composer/tmp-' . md5($package . spl_object_hash($package)) . '.' . $extension, '.');
+        return rtrim($this->config->get('vendor-dir') . '/composer/tmp-' . hash('md5', $package . spl_object_hash($package)) . '.' . $extension, '.');
     }
 
     /**
