@@ -19,12 +19,7 @@ namespace Composer\Downloader;
  */
 class FilesystemException extends \Exception
 {
-    /**
-     * @param string          $message
-     * @param int             $code
-     * @param \Exception|null $previous
-     */
-    public function __construct(string $message = '', int $code = 0, \Exception $previous = null)
+    public function __construct(string $message = '', int $code = 0, ?\Exception $previous = null)
     {
         parent::__construct("Filesystem exception: \n".$message, $code, $previous);
     }
