@@ -324,7 +324,9 @@ class Factory
 
         // Load config and override with local config/auth config
         $config = static::createConfig($io, $cwd);
+        $isGlobal = $localConfigSource !== Config::SOURCE_UNKNOWN && realpath($config->get('home')) === realpath(dirname($localConfigSource));
         $config->merge($localConfig, $localConfigSource);
+
         if (isset($composerFile)) {
             $io->writeError('Loading config file ' . $composerFile .' ('.realpath($composerFile).')', true, IOInterface::DEBUG);
             $config->setConfigSource(new JsonConfigSource(new JsonFile(realpath($composerFile), null, $io)));
@@ -346,6 +348,9 @@ class Factory
         // initialize composer
         $composer = $fullLoad ? new Composer() : new PartialComposer();
         $composer->setConfig($config);
+        if ($isGlobal) {
+            $composer->setGlobal();
+        }
 
         if ($fullLoad) {
             // load auth configs into the IO instance
@@ -429,14 +434,14 @@ class Factory
 
         if ($composer instanceof Composer) {
             $globalComposer = null;
-            if (realpath($config->get('home')) !== $cwd) {
+            if (!$composer->isGlobal()) {
                 $globalComposer = $this->createGlobalComposer($io, $config, $disablePlugins, $disableScripts);
             }
 
             $pm = $this->createPluginManager($io, $composer, $globalComposer, $disablePlugins);
             $composer->setPluginManager($pm);
 
-            if (realpath($config->get('home')) === $cwd) {
+            if ($composer->isGlobal()) {
                 $pm->setRunningInGlobalDir(true);
             }
 
