@@ -15,11 +15,18 @@ namespace Composer\Filter\PlatformRequirementFilter;
 final class IgnoreNothingPlatformRequirementFilter implements PlatformRequirementFilterInterface
 {
     /**
-     * @param string $req
      * @return false
      */
     public function isIgnored(string $req): bool
     {
         return false;
     }
+
+    /**
+     * @return false
+     */
+    public function isUpperBoundIgnored(string $req): bool
+    {
+        return false;
+    }
 }
