@@ -213,7 +213,7 @@ class BinaryInstaller
         $binDir = ProcessExecutor::escape(dirname($binPath));
         $binFile = basename($binPath);
 
-        $binContents = file_get_contents($bin);
+        $binContents = (string) file_get_contents($bin, false, null, 0, 500);
         // For php files, we generate a PHP proxy instead of a shell one,
         // which allows calling the proxy with a custom php process
         if (Preg::isMatch('{^(#!.*\r?\n)?[\r\n\t ]*<\?php}', $binContents, $match)) {
@@ -224,8 +224,13 @@ class BinaryInstaller
             $globalsCode = '$GLOBALS[\'_composer_bin_dir\'] = __DIR__;'."\n";
             $phpunitHack1 = $phpunitHack2 = '';
             // Don't expose autoload path when vendor dir was not set in custom installers
-            if ($this->vendorDir) {
-                $globalsCode .= '$GLOBALS[\'_composer_autoload_path\'] = ' . $this->filesystem->findShortestPathCode($link, $this->vendorDir . '/autoload.php', false, true).";\n";
+            if ($this->vendorDir !== null) {
+                // ensure comparisons work accurately if the CWD is a symlink, as $link is realpath'd already
+                $vendorDirReal = realpath($this->vendorDir);
+                if ($vendorDirReal === false) {
+                    $vendorDirReal = $this->vendorDir;
+                }
+                $globalsCode .= '$GLOBALS[\'_composer_autoload_path\'] = ' . $this->filesystem->findShortestPathCode($link, $vendorDirReal . '/autoload.php', false, true).";\n";
             }
             // Add workaround for PHPUnit process isolation
             if ($this->filesystem->normalizePath($bin) === $this->filesystem->normalizePath($this->vendorDir.'/phpunit/phpunit/phpunit')) {
@@ -237,7 +242,7 @@ class BinaryInstaller
                 $data = str_replace(\'__DIR__\', var_export(dirname($this->realpath), true), $data);
                 $data = str_replace(\'__FILE__\', var_export($this->realpath, true), $data);';
             }
-            if (trim((string) $match[0]) !== '<?php') {
+            if (trim($match[0]) !== '<?php') {
                 $streamHint = ' using a stream wrapper to prevent the shebang from being output on PHP<8'."\n *";
                 $streamProxyCode = <<<STREAMPROXY
 if (PHP_VERSION_ID < 80000) {
@@ -401,7 +406,7 @@ if [ -n "\$bashSource" ]; then
     fi
 fi
 
-"\${dir}/$binFile" "\$@"
+exec "\${dir}/$binFile" "\$@"
 
 PROXY;
     }
