@@ -12,8 +12,9 @@
 
 namespace Composer\Package\Archiver;
 
-use ZipArchive;
 use Composer\Util\Filesystem;
+use Composer\Util\Platform;
+use ZipArchive;
 
 /**
  * @author Jan Prieser <jan@prieser.net>
@@ -44,15 +45,17 @@ class ZipArchiver implements ArchiverInterface
             $files = new ArchivableFilesFinder($sources, $excludes, $ignoreFilters);
             foreach ($files as $file) {
                 /** @var \Symfony\Component\Finder\SplFileInfo $file */
-                $filepath = strtr($file->getPath()."/".$file->getFilename(), '\\', '/');
-                $localname = $filepath;
-                if (strpos($localname, $sources . '/') === 0) {
-                    $localname = substr($localname, strlen($sources . '/'));
+                $filepath = $file->getPathname();
+                $relativePath = $file->getRelativePathname();
+
+                if (Platform::isWindows()) {
+                    $relativePath = strtr($relativePath, '\\', '/');
                 }
+
                 if ($file->isDir()) {
-                    $zip->addEmptyDir($localname);
+                    $zip->addEmptyDir($relativePath);
                 } else {
-                    $zip->addFile($filepath, $localname);
+                    $zip->addFile($filepath, $relativePath);
                 }
 
                 /**
@@ -64,7 +67,7 @@ class ZipArchiver implements ArchiverInterface
                     /**
                      * Ensure to preserve the permission umasks for the filepath in the archive.
                      */
-                    $zip->setExternalAttributesName($localname, ZipArchive::OPSYS_UNIX, $perms << 16);
+                    $zip->setExternalAttributesName($relativePath, ZipArchive::OPSYS_UNIX, $perms << 16);
                 }
             }
             if ($zip->close()) {
