@@ -40,8 +40,7 @@ abstract class BasePackage implements PackageInterface
     public const STABILITY_ALPHA = 15;
     public const STABILITY_DEV = 20;
 
-    /** @var array<string, self::STABILITY_*> */
-    public static $stabilities = [
+    public const STABILITIES = [
         'stable' => self::STABILITY_STABLE,
         'RC' => self::STABILITY_RC,
         'beta' => self::STABILITY_BETA,
@@ -49,6 +48,14 @@ abstract class BasePackage implements PackageInterface
         'dev' => self::STABILITY_DEV,
     ];
 
+    /**
+     * @deprecated
+     * @readonly
+     * @var array<key-of<BasePackage::STABILITIES>, self::STABILITY_*>
+     * @phpstan-ignore property.readOnlyByPhpDocDefaultValue
+     */
+    public static $stabilities = self::STABILITIES;
+
     /**
      * READ-ONLY: The package id, public for fast access in dependency solver
      * @var int
@@ -234,7 +241,7 @@ abstract class BasePackage implements PackageInterface
      */
     public function getStabilityPriority(): int
     {
-        return self::$stabilities[$this->getStability()];
+        return self::STABILITIES[$this->getStability()];
     }
 
     public function __clone()
