@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -10,11 +10,9 @@
  * file that was distributed with this source code.
  */
 
-/**
- * @param string $file
- * @return ?\Composer\Autoload\ClassLoader
- */
-function includeIfExists($file)
+use Composer\Autoload\ClassLoader;
+
+function includeIfExists(string $file): ?ClassLoader
 {
     return file_exists($file) ? include $file : null;
 }
