@@ -54,7 +54,7 @@ class LicensesCommandTest extends TestCase
     public function testBasicRun(): void
     {
         $appTester = $this->getApplicationTester();
-        $this->assertSame(0, $appTester->run(['command' => 'license']));
+        self::assertSame(0, $appTester->run(['command' => 'license']));
 
         $expected = [
             ["Name:", "test/pkg"],
@@ -78,14 +78,17 @@ class LicensesCommandTest extends TestCase
                 continue;
             }
 
-            $this->assertMatchesRegularExpression("/" . implode("\s+", $expected[$i]) . "/", $line);
+            if (!isset($expected[$i])) {
+                $this->fail('Got more output lines than expected');
+            }
+            self::assertMatchesRegularExpression("/" . implode("\s+", $expected[$i]) . "/", $line);
         }
     }
 
     public function testNoDev(): void
     {
         $appTester = $this->getApplicationTester();
-        $this->assertSame(0, $appTester->run(['command' => 'license', '--no-dev' => true]));
+        self::assertSame(0, $appTester->run(['command' => 'license', '--no-dev' => true]));
 
         $expected = [
             ["Name:", "test/pkg"],
@@ -108,14 +111,17 @@ class LicensesCommandTest extends TestCase
                 continue;
             }
 
-            $this->assertMatchesRegularExpression("/" . implode("\s+", $expected[$i]) . "/", $line);
+            if (!isset($expected[$i])) {
+                $this->fail('Got more output lines than expected');
+            }
+            self::assertMatchesRegularExpression("/" . implode("\s+", $expected[$i]) . "/", $line);
         }
     }
 
     public function testFormatJson(): void
     {
         $appTester = $this->getApplicationTester();
-        $this->assertSame(0, $appTester->run(['command' => 'license', '--format' => 'json'], ['capture_stderr_separately' => true]));
+        self::assertSame(0, $appTester->run(['command' => 'license', '--format' => 'json'], ['capture_stderr_separately' => true]));
 
         $expected = [
             "name" => "test/pkg",
@@ -147,13 +153,13 @@ class LicensesCommandTest extends TestCase
             ]
         ];
 
-        $this->assertSame($expected, json_decode($appTester->getDisplay(), true));
+        self::assertSame($expected, json_decode($appTester->getDisplay(), true));
     }
 
     public function testFormatSummary(): void
     {
         $appTester = $this->getApplicationTester();
-        $this->assertSame(0, $appTester->run(['command' => 'license', '--format' => 'summary']));
+        self::assertSame(0, $appTester->run(['command' => 'license', '--format' => 'summary']));
 
         $expected = [
             ['-', '-'],
@@ -170,7 +176,7 @@ class LicensesCommandTest extends TestCase
         foreach ($expected as $i => $expect) {
             [$key, $value] = $expect;
 
-            $this->assertMatchesRegularExpression("/$key\s+$value/", $lines[$i]);
+            self::assertMatchesRegularExpression("/$key\s+$value/", $lines[$i]);
         }
     }
 
