@@ -25,7 +25,7 @@ final class PlatformRequirementFilterFactoryTest extends TestCase
      */
     public function testFromBoolOrList($boolOrList, $expectedInstance): void
     {
-        $this->assertInstanceOf($expectedInstance, PlatformRequirementFilterFactory::fromBoolOrList($boolOrList));
+        self::assertInstanceOf($expectedInstance, PlatformRequirementFilterFactory::fromBoolOrList($boolOrList));
     }
 
     /**
@@ -52,13 +52,13 @@ final class PlatformRequirementFilterFactoryTest extends TestCase
     {
         $platformRequirementFilter = PlatformRequirementFilterFactory::ignoreAll();
 
-        $this->assertInstanceOf('Composer\Filter\PlatformRequirementFilter\IgnoreAllPlatformRequirementFilter', $platformRequirementFilter);
+        self::assertInstanceOf('Composer\Filter\PlatformRequirementFilter\IgnoreAllPlatformRequirementFilter', $platformRequirementFilter);
     }
 
     public function testIgnoreNothing(): void
     {
         $platformRequirementFilter = PlatformRequirementFilterFactory::ignoreNothing();
 
-        $this->assertInstanceOf('Composer\Filter\PlatformRequirementFilter\IgnoreNothingPlatformRequirementFilter', $platformRequirementFilter);
+        self::assertInstanceOf('Composer\Filter\PlatformRequirementFilter\IgnoreNothingPlatformRequirementFilter', $platformRequirementFilter);
     }
 }
