@@ -27,8 +27,12 @@ class ComposerSchemaTest extends TestCase
             [
                 'property' => 'name',
                 'message' => 'Does not match the regex pattern ^[a-z0-9]([_.-]?[a-z0-9]+)*/[a-z0-9](([_.]|-{1,2})?[a-z0-9]+)*$',
-                'constraint' => 'pattern',
-                'pattern' => '^[a-z0-9]([_.-]?[a-z0-9]+)*/[a-z0-9](([_.]|-{1,2})?[a-z0-9]+)*$',
+                'constraint' => [
+                    'name' => 'pattern',
+                    'params' => [
+                        'pattern' => '^[a-z0-9]([_.-]?[a-z0-9]+)*/[a-z0-9](([_.]|-{1,2})?[a-z0-9]+)*$',
+                    ]
+                ],
             ],
         ];
 
@@ -38,6 +42,63 @@ class ComposerSchemaTest extends TestCase
         self::assertEquals($expectedError, $this->check($json));
     }
 
+    public function versionProvider(): array
+    {
+        return [
+            ['1.0.0', true],
+            ['1.0.2', true],
+            ['1.1.0', true],
+            ['1.0.0-dev', true],
+            ['1.0.0-alpha3', true],
+            ['1.0.0-beta232', true],
+            ['10.4.13beta.2', true],
+            ['1.0.0.RC.15-dev', true],
+            ['1.0.0-RC', true],
+            ['v2.0.4-p', true],
+            ['dev-master', true],
+            ['0.2.5.4', true],
+            ['12345678-123456', true],
+            ['20100102-203040-p1', true],
+            ['2010-01-02.5', true],
+            ['0.2.5.4-rc.2', true],
+            ['dev-feature+issue-1', true],
+            ['1.0.0-alpha.3.1+foo/-bar', true],
+            ['00.01.03.04', true],
+            ['041.x-dev', true],
+            ['dev-foo bar', true],
+
+            ['invalid', false],
+            ['1.0be', false],
+            ['1.0.0-meh', false],
+            ['feature-foo', false],
+            ['1.0 .2', false],
+        ];
+    }
+
+    /**
+     * @dataProvider versionProvider
+     */
+    public function testVersionPattern(string $version, bool $isValid): void
+    {
+        $json = '{"name": "vendor/package", "description": "description", "version": "' . $version . '"}';
+        if ($isValid) {
+            self::assertTrue($this->check($json));
+        } else {
+            self::assertEquals([
+                [
+                    'property' => 'version',
+                    'message' => 'Does not match the regex pattern ^v?\\d+(?:[.-]\\d+){0,3}[._-]?(?:(?:stable|beta|b|RC|rc|alpha|a|patch|pl|p)(?:(?:[.-]?\\d+)*+)?)?(?:[.-]?dev|\\.x-dev)?(?:\\+.*)?$|^dev-.*$',
+                    'constraint' => [
+                        'name' => 'pattern',
+                        'params' => [
+                            'pattern' => '^v?\\d+(?:[.-]\\d+){0,3}[._-]?(?:(?:stable|beta|b|RC|rc|alpha|a|patch|pl|p)(?:(?:[.-]?\\d+)*+)?)?(?:[.-]?dev|\\.x-dev)?(?:\\+.*)?$|^dev-.*$',
+                        ]
+                    ],
+                ],
+            ], $this->check($json));
+        }
+    }
+
     public function testOptionalAbandonedProperty(): void
     {
         $json = '{"name": "vendor/package", "description": "description", "abandoned": true}';
@@ -48,7 +109,11 @@ class ComposerSchemaTest extends TestCase
     {
         $json = '{"name": "vendor/package", "description": "description", "require": {"a": ["b"]} }';
         self::assertEquals([
-            ['property' => 'require.a', 'message' => 'Array value found, but a string is required', 'constraint' => 'type'],
+            [
+                'property' => 'require.a',
+                'message' => 'Array value found, but a string is required',
+                'constraint' => ['name' => 'type', 'params' => ['found' => 'array', 'expected' => 'a string']],
+            ],
         ], $this->check($json));
     }
 
@@ -58,8 +123,12 @@ class ComposerSchemaTest extends TestCase
             [
                 'property' => 'minimum-stability',
                 'message' => 'Does not have a value in the enumeration ["dev","alpha","beta","rc","RC","stable"]',
-                'constraint' => 'enum',
-                'enum' => ['dev', 'alpha', 'beta', 'rc', 'RC', 'stable'],
+                'constraint' => [
+                    'name' => 'enum',
+                    'params' => [
+                        'enum' => ['dev', 'alpha', 'beta', 'rc', 'RC', 'stable'],
+                    ],
+                ],
             ],
         ];
 
@@ -97,7 +166,8 @@ class ComposerSchemaTest extends TestCase
     private function check(string $json)
     {
         $validator = new Validator();
-        $validator->check(json_decode($json), (object) ['$ref' => 'file://' . JsonFile::COMPOSER_SCHEMA_PATH]);
+        $json = json_decode($json);
+        $validator->validate($json, (object) ['$ref' => 'file://' . JsonFile::COMPOSER_SCHEMA_PATH]);
 
         if (!$validator->isValid()) {
             $errors = $validator->getErrors();
