@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -17,11 +17,11 @@ use Composer\Installer\InstallationManager;
 
 class InstalledFilesystemRepositoryMock extends InstalledFilesystemRepository
 {
-    public function reload()
+    public function reload(): void
     {
     }
 
-    public function write($devMode, InstallationManager $installationManager)
+    public function write($devMode, InstallationManager $installationManager): void
     {
     }
 }
