@@ -1256,8 +1256,8 @@ Linked Version => 1.2.11',
             } else {
                 self::assertNotNull($package, sprintf('Expected to find package "%s"', $packageName));
                 self::assertSame($expectedVersion, $package->getPrettyVersion(), sprintf('Expected version %s for %s', $expectedVersion, $packageName));
-                $this->assertPackageLinks('replaces', $expectedReplaces, $package, $package->getReplaces());
-                $this->assertPackageLinks('provides', $expectedProvides, $package, $package->getProvides());
+                self::assertPackageLinks('replaces', $expectedReplaces, $package, $package->getReplaces());
+                self::assertPackageLinks('provides', $expectedProvides, $package, $package->getProvides());
             }
         }
     }
