@@ -25,15 +25,15 @@ class PlatformTest extends TestCase
     public function testExpandPath(): void
     {
         putenv('TESTENV=/home/test');
-        $this->assertEquals('/home/test/myPath', Platform::expandPath('%TESTENV%/myPath'));
-        $this->assertEquals('/home/test/myPath', Platform::expandPath('$TESTENV/myPath'));
-        $this->assertEquals((getenv('HOME') ?: getenv('USERPROFILE')) . '/test', Platform::expandPath('~/test'));
+        self::assertEquals('/home/test/myPath', Platform::expandPath('%TESTENV%/myPath'));
+        self::assertEquals('/home/test/myPath', Platform::expandPath('$TESTENV/myPath'));
+        self::assertEquals((getenv('HOME') ?: getenv('USERPROFILE')) . '/test', Platform::expandPath('~/test'));
     }
 
     public function testIsWindows(): void
     {
         // Compare 2 common tests for Windows to the built-in Windows test
-        $this->assertEquals(('\\' === DIRECTORY_SEPARATOR), Platform::isWindows());
-        $this->assertEquals(defined('PHP_WINDOWS_VERSION_MAJOR'), Platform::isWindows());
+        self::assertEquals(('\\' === DIRECTORY_SEPARATOR), Platform::isWindows());
+        self::assertEquals(defined('PHP_WINDOWS_VERSION_MAJOR'), Platform::isWindows());
     }
 }
